package org.rcisoft.business.overview.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.overview.service.OverViewService;
import org.rcisoft.core.constant.MessageConstant;
import org.rcisoft.core.model.PersistModel;
import org.rcisoft.core.result.Result;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * Created by JiChao on 2018/4/11.
 * 概览接口
 */
@Api(tags = "能耗管理")
@RestController
@RequestMapping("overview")
public class OverViewController {

    @Autowired
    private OverViewService overViewServiceImpl;

    /** --------------用能概况-------------- */
    @ApiOperation(value="根据项目类型id查询水、电、气24小时的价格", notes="返回水电气三种设备24小时价格")
    @ApiImplicitParams({@ApiImplicitParam(name = "proId", value = "项目类型主键", required = true, dataType = "字符串")})
    @RequestMapping("/getPrice/{proId:\\w+}")
    public Result getPrice(@PathVariable String proId) {
        return Result.builder(new PersistModel(1), MessageConstant.MESSAGE_ALERT_SUCCESS, MessageConstant.MESSAGE_ALERT_ERROR, overViewServiceImpl.getPrice(proId));
    }

    @ApiOperation(value="用量和费用统计", notes="用量和费用统计")
    @ApiImplicitParams({@ApiImplicitParam(name = "proId", value = "项目类型主键", required = true, dataType = "字符串")})
    @RequestMapping("/getEnergy/{proId:\\w+}")
    public Result getEnergy(@PathVariable String proId) {
        return Result.builder(new PersistModel(1), MessageConstant.MESSAGE_ALERT_SUCCESS, MessageConstant.MESSAGE_ALERT_ERROR, overViewServiceImpl.countAmountAndPrice(proId));
    }

    @ApiOperation(value="运行费用统计", notes="运行费用统计")
    @ApiImplicitParams({@ApiImplicitParam(name = "proId", value = "项目类型主键", required = true, dataType = "字符串"),
                        @ApiImplicitParam(name = "date", value = "0：今日，-1：昨日，1：明日", required = true, dataType = "数字")
    })
    @RequestMapping("/countDailyPrice")
    public Result countDailyPrice(@RequestParam String proId, @RequestParam Integer date) {
        return Result.builder(new PersistModel(1), MessageConstant.MESSAGE_ALERT_SUCCESS, MessageConstant.MESSAGE_ALERT_ERROR, overViewServiceImpl.countDailyPrice(proId, date));
    }

    @ApiOperation(value="耗能拆分统计", notes="耗能拆分统计")
    @ApiImplicitParams({@ApiImplicitParam(name = "proId", value = "项目类型主键", required = true, dataType = "字符串"),
            @ApiImplicitParam(name = "type", value = "水电气类型，1：水，2：电，3：气", required = true, dataType = "数字"),
            @ApiImplicitParam(name = "date", value = "0：今日，-1：昨日，1：明日", required = true, dataType = "数字")
    })
    @RequestMapping("/countEnergySplit")
    public Result countEnergySplit(@RequestParam String proId, @RequestParam Integer type, @RequestParam Integer date) {
        return Result.builder(new PersistModel(1), MessageConstant.MESSAGE_ALERT_SUCCESS, MessageConstant.MESSAGE_ALERT_ERROR, overViewServiceImpl.countEnergySplit(proId, type, date));
    }

    @ApiOperation(value="运行费用排名", notes="运行费用排名")
    @ApiImplicitParams({@ApiImplicitParam(name = "proId", value = "项目类型主键", required = true, dataType = "字符串"),
            @ApiImplicitParam(name = "date", value = "0：今日，-1：昨日，1：明日", required = true, dataType = "数字")
    })
    @RequestMapping("/getPriceRank")
    public Result getPriceRank(@RequestParam String proId, @RequestParam Integer date) {
        return Result.builder(new PersistModel(1), MessageConstant.MESSAGE_ALERT_SUCCESS, MessageConstant.MESSAGE_ALERT_ERROR, overViewServiceImpl.getPriceRank(proId, date));
    }

    /** -------------用能比较--------------- */

    @ApiOperation(value="建筑单位面积用量标准", notes="水电气的行业标准、建议标准、国家标准")
    @ApiImplicitParams({@ApiImplicitParam(name = "proId", value = "项目类型主键", required = true, dataType = "字符串")})
    @RequestMapping("/getStandard/{proId:\\w+}")
    public Result getStandard(@PathVariable String proId) {
        return Result.builder(new PersistModel(1), MessageConstant.MESSAGE_ALERT_SUCCESS, MessageConstant.MESSAGE_ALERT_ERROR, overViewServiceImpl.getStandard(proId));
    }

    @ApiOperation(value="建筑单位面积用量年度", notes="建筑单位面积用量年度，三年的数据")
    @ApiImplicitParams({@ApiImplicitParam(name = "proId", value = "项目类型主键", required = true, dataType = "字符串")})
    @RequestMapping("/getUnitArea/{proId:\\w+}")
    public Result getUnitArea(@PathVariable String proId) {
        return Result.builder(new PersistModel(1), MessageConstant.MESSAGE_ALERT_SUCCESS, MessageConstant.MESSAGE_ALERT_ERROR, overViewServiceImpl.getUnitArea(proId));
    }

    @ApiOperation(value="用能比较", notes="返回两组数据")
    @ApiImplicitParams({@ApiImplicitParam(name = "proId", value = "项目类型主键", required = true, dataType = "字符串"),
            @ApiImplicitParam(name = "year", value = "年份，如：2018", required = true, dataType = "字符串或数字"),
            @ApiImplicitParam(name = "month", value = "月份，如：6", required = true, dataType = "字符串或数字"),
            @ApiImplicitParam(name = "type", value = "水电气类型，1：水，2：电，3：气", required = true, dataType = "字符串或数字"),
            @ApiImplicitParam(name = "cType", value = "1：同比，2：环比", required = true, dataType = "字符串或数字"),
    })
    @RequestMapping("/getEnergyCompare")
    public Result getEnergyCompare(@RequestParam String proId, @RequestParam String year, @RequestParam String month, @RequestParam Integer type, @RequestParam Integer cType) {
        return Result.builder(new PersistModel(1), MessageConstant.MESSAGE_ALERT_SUCCESS, MessageConstant.MESSAGE_ALERT_ERROR, overViewServiceImpl.getEnergyCompare(proId, year, month, type, cType));
    }

    /** -------------碳排放量--------------- */
    @ApiOperation(value="查询碳排放量", notes="8条数据，没有“年环比”数据")
    @ApiImplicitParams({@ApiImplicitParam(name = "proId", value = "项目类型主键", required = true, dataType = "字符串")})
    @RequestMapping("/getEmission/{proId:\\w+}")
    public Result getEmission(@PathVariable String proId) {
        return Result.builder(new PersistModel(1), MessageConstant.MESSAGE_ALERT_SUCCESS, MessageConstant.MESSAGE_ALERT_ERROR, overViewServiceImpl.getEmission(proId));
    }

    @ApiOperation(value="查询累计减排", notes="查询累计减排")
    @ApiImplicitParams({@ApiImplicitParam(name = "proId", value = "项目类型主键", required = true, dataType = "字符串")})
    @RequestMapping("/getEmissionStat/{proId:\\w+}")
    public Result getEmissionStat(@PathVariable String proId) {
        return Result.builder(new PersistModel(1), MessageConstant.MESSAGE_ALERT_SUCCESS, MessageConstant.MESSAGE_ALERT_ERROR, overViewServiceImpl.getEmissionStat(proId));
    }

    @ApiOperation(value="统计月排放", notes="统计月排放")
    @ApiImplicitParams({@ApiImplicitParam(name = "proId", value = "项目类型主键", required = true, dataType = "字符串"),
                        @ApiImplicitParam(name = "year", value = "年份，如：2018", required = true, dataType = "字符串或数字")
    })
    @RequestMapping("/statEmissionMonth")
    public Result statEmissionMonth(@RequestParam String proId, @RequestParam int year) {
        return Result.builder(new PersistModel(1), MessageConstant.MESSAGE_ALERT_SUCCESS, MessageConstant.MESSAGE_ALERT_ERROR, overViewServiceImpl.statEmissionMonth(proId, year));
    }

    @ApiOperation(value="统计日排放", notes="统计日排放")
    @ApiImplicitParams({@ApiImplicitParam(name = "proId", value = "项目类型主键", required = true, dataType = "字符串"),
            @ApiImplicitParam(name = "year", value = "年份，如：2018", required = true, dataType = "字符串或数字"),
            @ApiImplicitParam(name = "month", value = "月份，如：6", required = true, dataType = "字符串或数字")
    })
    @RequestMapping("/statEmissionDay")
    public Result statEmissionDay(@RequestParam String proId, @RequestParam int year, @RequestParam int month) {
        return Result.builder(new PersistModel(1), MessageConstant.MESSAGE_ALERT_SUCCESS, MessageConstant.MESSAGE_ALERT_ERROR, overViewServiceImpl.statEmissionDay(proId, year, month));
    }

    /** -------------碳排放量--------------- */
    @ApiOperation(value="年用能计划", notes="年用能计划")
    @ApiImplicitParams({@ApiImplicitParam(name = "proId", value = "项目类型主键", required = true, dataType = "字符串"),
            @ApiImplicitParam(name = "year", value = "年份，如：2018", required = true, dataType = "字符串或数字")
    })
    @RequestMapping("/statEnergyPlanYear")
    public Result statEnergyPlanYear(@RequestParam String proId, @RequestParam String year) {
        return Result.builder(new PersistModel(1), MessageConstant.MESSAGE_ALERT_SUCCESS, MessageConstant.MESSAGE_ALERT_ERROR, overViewServiceImpl.statEnergyPlanYear(proId, year));
    }

    @ApiOperation(value="月用能计划", notes="月用能计划")
    @ApiImplicitParams({@ApiImplicitParam(name = "proId", value = "项目类型主键", required = true, dataType = "字符串"),
            @ApiImplicitParam(name = "year", value = "年份，如：2018", required = true, dataType = "字符串或数字"),
            @ApiImplicitParam(name = "month", value = "月份，如：6", required = true, dataType = "字符串或数字")
    })
    @RequestMapping("/statEnergyPlanMonth")
    public Result statEnergyPlanMonth(@RequestParam String proId, @RequestParam String year, @RequestParam String month) {
        return Result.builder(new PersistModel(1), MessageConstant.MESSAGE_ALERT_SUCCESS, MessageConstant.MESSAGE_ALERT_ERROR, overViewServiceImpl.statEnergyPlanMonth(proId, year, month));
    }

    @ApiOperation(value="日用能计划", notes="日用能计划")
    @ApiImplicitParams({@ApiImplicitParam(name = "proId", value = "项目类型主键", required = true, dataType = "字符串"),
            @ApiImplicitParam(name = "year", value = "年份，如：2018", required = true, dataType = "字符串或数字"),
            @ApiImplicitParam(name = "month", value = "月份，如：6", required = true, dataType = "字符串或数字"),
            @ApiImplicitParam(name = "day", value = "日，如：1", required = true, dataType = "字符串或数字")
    })
    @RequestMapping("/statEnergyPlanDay")
    public Result statEnergyPlanDay(@RequestParam String proId, @RequestParam String year, @RequestParam String month, @RequestParam String day) {
        return Result.builder(new PersistModel(1), MessageConstant.MESSAGE_ALERT_SUCCESS, MessageConstant.MESSAGE_ALERT_ERROR, overViewServiceImpl.statEnergyPlanDay(proId, year, month, day));
    }

}
